﻿using SchoolScheduleContracts.BindingModels;
using SchoolScheduleContracts.BusinessLogicsContracts;
using SchoolScheduleDataModels.Enums;
using SchoolScheduleDataModels.Models;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.VisualStyles.VisualStyleElement;

namespace SchoolSchedule
{
	public partial class EditStudentForm : Form
	{
		public IStudentModel student { get; set; } = null;
		public ILessonModel lesson { get; set; } = null;
		IStudentLogic _logic;
		public EditStudentForm(IStudentLogic logic)
		{
			InitializeComponent();
			_logic = logic;
		}

		private void EditStudentForm_Load(object sender, EventArgs e)
		{
			comboBox1.DataSource = Enum.GetValues(typeof(StudentStatus));
		}
		public void LoadData()
		{
			if (student.Attendance[lesson.Id].Item3 != null)
				textBox1.Text = student.Attendance[lesson.Id].Item3.ToString();
		}

		private void AddButton_Click(object sender, EventArgs e)
		{
			if (comboBox1.SelectedValue == null)
			{
				MessageBox.Show("Выберите классного руководителя", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			if (string.IsNullOrEmpty(textBox1.Text))
			{
				MessageBox.Show("Заполните поле оценка", "Ошибка",
			   MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}
			try
			{
				int year = int.Parse(textBox1.Text);
				if (!(year >= 2 && year <= 5) && year != 0)
				{
					throw new Exception("Ошибка при создании.");
				}
				student.Attendance[lesson.Id] = (student.Attendance[lesson.Id].Item1, (StudentStatus)comboBox1.SelectedValue, (year == 0 ? null : year));
				StudentBindingModel model = new StudentBindingModel
				{
					Id = student.Id,
					GradeId = student.GradeId,
					FullName = student.FullName,
					Attendance = student.Attendance
				};
				var operationResult = _logic.Update(model);
				if (!operationResult)
				{
					throw new Exception("Ошибка при создании заказа.");
				}
				MessageBox.Show("Сохранение прошло успешно", "Сообщение",
			   MessageBoxButtons.OK, MessageBoxIcon.Information);
				DialogResult = DialogResult.OK;
				Close();
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK,
			   MessageBoxIcon.Error);
			}

		}

		private void CancelButton_Click(object sender, EventArgs e)
		{
			DialogResult = DialogResult.Cancel;
			Close();
		}
	}
}
